@@ -6,8 +6,8 @@ test! {
 foo:
   echo {{arch()}} {{os()}} {{os_family()}}
 "#,
-  stdout:   format!("{} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
-  stderr:   format!("echo {} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
+  stdout:   format!("{} {} {}\n", target::arch(), target::os(), target::family()).as_str(),
+  stderr:   format!("echo {} {} {}\n", target::arch(), target::os(), target::family()).as_str(),
 }
 
 test! {
@@ -20,8 +20,8 @@ f := os_family()
 foo:
   echo {{a}} {{o}} {{f}}
 "#,
-  stdout:   format!("{} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
-  stderr:   format!("echo {} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
+  stdout:   format!("{} {} {}\n", target::arch(), target::os(), target::family()).as_str(),
+  stderr:   format!("echo {} {} {}\n", target::arch(), target::os(), target::family()).as_str(),
 }
 
 #[cfg(not(windows))]
@@ -249,8 +249,8 @@ test! {
 foo a=arch() o=os() f=os_family():
   echo {{a}} {{o}} {{f}}
 "#,
-  stdout:   format!("{} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
-  stderr:   format!("echo {} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
+  stdout:   format!("{} {} {}\n", target::arch(), target::os(), target::family()).as_str(),
+  stderr:   format!("echo {} {} {}\n", target::arch(), target::os(), target::family()).as_str(),
 }
 
 test! {
@@ -302,3 +302,104 @@ test! {
   stdout: "foofoofoo\n",
   stderr: "echo foofoofoo\n",
 }
+
+fn assert_eval_eq(expression: &str, result: &str) {
+  Test::new()
+    .justfile(format!("x := {}", expression))
+    .args(&["--evaluate", "x"])
+    .stdout(result)
+    .unindent_stdout(false)
+    .run();
+}
+
+#[test]
+fn trim_end_matches() {
+  assert_eval_eq("trim_end_matches('foo', 'o')", "f");
+  assert_eval_eq("trim_end_matches('fabab', 'ab')", "f");
+  assert_eval_eq("trim_end_matches('fbaabab', 'ab')", "fba");
+}
+
+#[test]
+fn trim_end_match() {
+  assert_eval_eq("trim_end_match('foo', 'o')", "fo");
+  assert_eval_eq("trim_end_match('fabab', 'ab')", "fab");
+}
+
+#[test]
+fn trim_start_matches() {
+  assert_eval_eq("trim_start_matches('oof', 'o')", "f");
+  assert_eval_eq("trim_start_matches('ababf', 'ab')", "f");
+  assert_eval_eq("trim_start_matches('ababbaf', 'ab')", "baf");
+}
+
+#[test]
+fn trim_start_match() {
+  assert_eval_eq("trim_start_match('oof', 'o')", "of");
+  assert_eval_eq("trim_start_match('ababf', 'ab')", "abf");
+}
+
+#[test]
+fn trim_start() {
+  assert_eval_eq("trim_start('  f  ')", "f  ");
+}
+
+#[test]
+fn trim_end() {
+  assert_eval_eq("trim_end('  f  ')", "  f");
+}
+
+#[test]
+#[cfg(not(windows))]
+fn join() {
+  assert_eval_eq("join('a', 'b', 'c', 'd')", "a/b/c/d");
+  assert_eval_eq("join('a', '/b', 'c', 'd')", "/b/c/d");
+  assert_eval_eq("join('a', '/b', '/c', 'd')", "/c/d");
+  assert_eval_eq("join('a', '/b', '/c', '/d')", "/d");
+}
+
+#[test]
+#[cfg(windows)]
+fn join() {
+  assert_eval_eq("join('a', 'b', 'c', 'd')", "a\\b\\c\\d");
+  assert_eval_eq("join('a', '\\b', 'c', 'd')", "\\b\\c\\d");
+  assert_eval_eq("join('a', '\\b', '\\c', 'd')", "\\c\\d");
+  assert_eval_eq("join('a', '\\b', '\\c', '\\d')", "\\d");
+}
+
+#[test]
+fn join_argument_count_error() {
+  Test::new()
+    .justfile("x := join('a')")
+    .args(&["--evaluate"])
+    .stderr(
+      "
+      error: Function `join` called with 1 argument but takes 2 or more
+        |
+      1 | x := join(\'a\')
+        |      ^^^^
+      ",
+    )
+    .status(EXIT_FAILURE)
+    .run();
+}
+
+#[test]
+fn test_path_exists_filepath_exist() {
+  Test::new()
+    .tree(tree! {
+      testfile: ""
+    })
+    .justfile("x := path_exists('testfile')")
+    .args(&["--evaluate", "x"])
+    .stdout("true")
+    .run();
+}
+
+#[test]
+fn test_path_exists_filepath_doesnt_exist() {
+  Test::new()
+    .justfile("x := path_exists('testfile')")
+    .args(&["--evaluate", "x"])
+    .stdout("false")
+    .run();
+}
